==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/redshift/kotlin/inputs/ScheduledActionTargetActionResumeClusterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.redshift.kotlin.inputs

import com.pulumi.aws.redshift.inputs.ScheduledActionTargetActionResumeClusterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property clusterIdentifier The identifier of the cluster to be resumed.
 */
public data class ScheduledActionTargetActionResumeClusterArgs(
    public val clusterIdentifier: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.redshift.inputs.ScheduledActionTargetActionResumeClusterArgs> {
    override fun toJava(): com.pulumi.aws.redshift.inputs.ScheduledActionTargetActionResumeClusterArgs =
        com.pulumi.aws.redshift.inputs.ScheduledActionTargetActionResumeClusterArgs.builder()
            .clusterIdentifier(clusterIdentifier.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ScheduledActionTargetActionResumeClusterArgs].
 */
@PulumiTagMarker
public class ScheduledActionTargetActionResumeClusterArgsBuilder internal constructor() {
    private var clusterIdentifier: Output<String>? = null

    /**
     * @param value The identifier of the cluster to be resumed.
     */
    @JvmName("ldstsxpcqiajsojf")
    public suspend fun clusterIdentifier(`value`: Output<String>) {
        this.clusterIdentifier = value
    }

    /**
     * @param value The identifier of the cluster to be resumed.
     */
    @JvmName("kypduajfiiwnvlkm")
    public suspend fun clusterIdentifier(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterIdentifier = mapped
    }

    internal fun build(): ScheduledActionTargetActionResumeClusterArgs =
        ScheduledActionTargetActionResumeClusterArgs(
            clusterIdentifier = clusterIdentifier ?: throw PulumiNullFieldException("clusterIdentifier"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/redshift/kotlin/inputs/ScheduledActionTargetActionResumeClusterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.redshift.kotlin.inputs

import com.pulumi.aws.redshift.inputs.ScheduledActionTargetActionResumeClusterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property clusterIdentifier The identifier of the cluster to be resumed.
 */
public data class ScheduledActionTargetActionResumeClusterArgs(
    public val clusterIdentifier: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.redshift.inputs.ScheduledActionTargetActionResumeClusterArgs> {
    override fun toJava(): com.pulumi.aws.redshift.inputs.ScheduledActionTargetActionResumeClusterArgs = com.pulumi.aws.redshift.inputs.ScheduledActionTargetActionResumeClusterArgs.builder()
        .clusterIdentifier(clusterIdentifier.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ScheduledActionTargetActionResumeClusterArgs].
 */
@PulumiTagMarker
public class ScheduledActionTargetActionResumeClusterArgsBuilder internal constructor() {
    private var clusterIdentifier: Output<String>? = null

    /**
     * @param value The identifier of the cluster to be resumed.
     */
    @JvmName("vsormlyewypeikja")
    public suspend fun clusterIdentifier(`value`: Output<String>) {
        this.clusterIdentifier = value
    }

    /**
     * @param value The identifier of the cluster to be resumed.
     */
    @JvmName("icwvaurdeupkyxsd")
    public suspend fun clusterIdentifier(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterIdentifier = mapped
    }

    internal fun build(): ScheduledActionTargetActionResumeClusterArgs =
        ScheduledActionTargetActionResumeClusterArgs(
            clusterIdentifier = clusterIdentifier ?: throw PulumiNullFieldException("clusterIdentifier"),
        )
}
